@@ -1,7 +1,7 @@
-# Copyright (c) 2007 CentralNic Ltd. All rights reserved. This program is
+# Copyright (c) 2010 CentralNic Ltd. All rights reserved. This program is
 # free software; you can redistribute it and/or modify it under the same
 # terms as Perl itself.
-# $Id: CNic.pm,v 1.59 2009/08/28 11:59:53 oliver Exp $
+# $Id: CNic.pm,v 1.62 2010/05/21 16:36:47 gavin Exp $
 package WWW::CNic;
 use LWP;
 use LWP::ConnCache;
@@ -11,7 +11,7 @@ use Digest::MD5 qw(md5_hex);
 use vars qw($VERSION $CONNECTION_CACHE);
 use strict;
 
-our $VERSION = '0.30';
+our $VERSION = '0.32';
 
 =pod
 
@@ -136,7 +136,7 @@ This method makes the transaction and returns an instance of a C<WWW::CNic::Resp
 
 =head1 COPYRIGHT
 
-This module is (c) 2004 CentralNic Ltd. All rights reserved. This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+This module is (c) 2010 CentralNic Ltd. All rights reserved. This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
 
 =head1 SEE ALSO
 
@@ -227,6 +227,9 @@ sub execute {
 		$self->{_command} eq 'reject_transfer'		&& return $self->_reject_transfer();
 		$self->{_command} eq 'list_outstanding_domains'	&& return $self->_list_outstanding_domains();
 		$self->{_command} eq 'submit_payment_batch'	&& return $self->_submit_payment_batch();
+		$self->{_command} eq 'registrant_transfer'	&& return $self->_registrant_transfer();
+		$self->{_command} eq 'lock_domain'		&& return $self->_lock_domain();
+		$self->{_command} eq 'unlock_domain'		&& return $self->_unlock_domain();
 		die("Invalid command '$self->{_command}'");
 	}
 }
@@ -845,6 +848,31 @@ sub _reject_transfer {
 	return WWW::CNic::Response::RejectTransfer->new($self->{_response}->{_raw});
 }
 
+sub _registrant_transfer {
+	my $self = shift;
+	$self->{_base} =~ s/^http:/https:/g;	# Requires SSL
+	die ("Missing username") if $self->{_username} eq '';
+	die ("Missing password") if $self->{_password} eq '';
+	die ("Missing domain") if ($self->{_params}->{domain} eq '');
+	die ("Missing registrant") if ($self->{_params}->{registrant} eq '');
+
+	my %params = (
+				user		=> $self->{_username},
+				password	=> $self->_crypt_md5($self->{_password}),
+				test		=> $self->{_test},
+	);
+
+    foreach my $key (keys(%{$self->{_params}})) {
+		$params{$key} = $self->{_params}->{$key};
+	}
+
+	my $url = "$self->{_base}/registrant_transfer";
+	my $req = POST($url, \%params);
+	$self->{_response}->{_raw} = $self->_get($req);
+	use WWW::CNic::Response::RegistrantTransfer;
+	return WWW::CNic::Response::RegistrantTransfer->new($self->{_response}->{_raw});
+}
+
 sub _list_outstanding_domains {
 	my $self = shift;
 	$self->{_base} =~ s/^http:/https:/g;	# Requires SSL
@@ -886,6 +914,44 @@ sub _submit_payment_batch {
 	return WWW::CNic::Response::SubmitPaymentBatch->new($self->{_response}->{_raw});
 }
 
+sub _lock_domain {
+	my $self = shift;
+	$self->{_base} =~ s/^http:/https:/g;	# Requires SSL
+	die("Missing username") if $self->{_username} eq '';
+	die("Missing password") if $self->{_password} eq '';
+	die("Missing domain")	if $self->{_domain}   eq '';
+	my %params = (
+				user		=> $self->{_username},
+				password	=> $self->_crypt_md5($self->{_password}),
+				test		=> $self->{_test},
+				domain		=> $self->{_domain},
+	);
+	my $url = "$self->{_base}/lock_domain";
+	my $req = POST($url, \%params);
+	$self->{_response}->{_raw} = $self->_get($req);
+	use WWW::CNic::Response::LockDomain;
+	return WWW::CNic::Response::LockDomain->new($self->{_response}->{_raw});
+}
+
+sub _unlock_domain {
+	my $self = shift;
+	$self->{_base} =~ s/^http:/https:/g;	# Requires SSL
+	die("Missing username") if $self->{_username} eq '';
+	die("Missing password") if $self->{_password} eq '';
+	die("Missing domain")	if $self->{_domain}   eq '';
+	my %params = (
+				user		=> $self->{_username},
+				password	=> $self->_crypt_md5($self->{_password}),
+				test		=> $self->{_test},
+				domain		=> $self->{_domain},
+	);
+	my $url = "$self->{_base}/unlock_domain";
+	my $req = POST($url, \%params);
+	$self->{_response}->{_raw} = $self->_get($req);
+	use WWW::CNic::Response::UnlockDomain;
+	return WWW::CNic::Response::UnlockDomain->new($self->{_response}->{_raw});
+}
+
 sub _get {
 	my ($self, $request) = @_;
 	my $response = $self->{_agent}->request($request);
