@@ -1,7 +1,7 @@
-# Copyright (c) 2007 CentralNic Ltd. All rights reserved. This program is
+# Copyright (c) 2010 CentralNic Ltd. All rights reserved. This program is
 # free software; you can redistribute it and/or modify it under the same
 # terms as Perl itself.
-# $Id: Cookbook.pm,v 1.46 2009/08/28 11:59:54 oliver Exp $
+# $Id: Cookbook.pm,v 1.52 2010/04/26 13:35:23 gavin Exp $
 
 package WWW::CNic::Cookbook;
 use vars qw($VERSION);
@@ -26,7 +26,7 @@ To enable test mode, simply set the C<test> argument on the constructor, like so
 
 	my $query = WWW::CNic->new(test => 1, ... );
 
-The test database is mirrored from the live database every 24 hours.
+You will also need to supply B<test account> credentials rather than production account credentials. These can be obtained from the Registrar Console.
 
 =head1 Getting Information about Domains
 
@@ -559,48 +559,6 @@ Using this service, you can delete an unwanted domain name. However, you must su
 
 In accordance with our policy, an e-mail will be sent to the domain's Client Handle informing them that the domain has been deleted.
 
-=head2 Declining Renewal for a Domain Name
-
-	my $query = WWW::CNic->new(
-		command		=> 'decline',
-		domain		=> $domain,
-		username	=> $handle,
-		password	=> $password,
-	);
-
-	my $response = $query->execute;
-
-	if ($response->is_success) {
-		print "Domain will not be renewed.\n";
-
-	} else {
-		printf("Error: %s\n", $response->error);
-
-	}
-
-I<Declining renewal> means that a domain name will not be renewed when it expires - it will simply be deleted upon expiry.
-
-=head2 Reversing a Declined Renewal
-
-	my $query = WWW::CNic->new(
-		command		=> 'undecline',
-		domain		=> $domain,
-		username	=> $handle,
-		password	=> $password,
-	);
-
-	my $response = $query->execute;
-
-	if ($response->is_success) {
-		print "Domain will be renewed upon expiry.\n";
-
-	} else {
-		printf("Error: %s\n", $response->error);
-
-	}
-
-This command lets you reinstate a domain name previously placed on Declined Renewal. When the domain name reaches its expiry, a renewal will be issued as normal.
-
 =head2 Requesting Reactivation of a Domain Name
 
 Domains that are on the "Pending Deletion" status may be reactivated upon
@@ -645,6 +603,8 @@ registrar account. A domain name may only be pushed if:
 
 =item the "gaining" registrar has not opted-out of the "push" system
 
+=item there are no unpaid registration or renewal fees against it
+
 =back
 
 	my $query = WWW::CNic->new(
@@ -666,8 +626,7 @@ registrar account. A domain name may only be pushed if:
 	}
 
 If the transaction is successful, the domain name will be immediately removed
-from your account. Any outstanding invoices will be credited to you and
-re-issued to the gaining account.
+from your account.
 
 If you are also listed as Technical Contact for the domain name, then this
 handle will also be changed to the gaining registrar account.
@@ -690,13 +649,15 @@ You can B<start> a transfer process for one or more domain names using the C<sta
 
 2. Our system sees the new request and sends an authorisation message to the B<losing> registrar. The status of the transfer is now C<pending>.
 
-3. The B<losing> registrar must then explicitly I<approve> or I<reject> the transfer request. The status of the transfer is now either C<approved> or C<rejected>.
+3. The B<losing> registrar may then explicitly I<approve> or I<reject> the transfer request within 5 days. The status of the transfer is now either C<approved> or C<rejected>.
 
 4. If the transfer was B<rejected>, the B<gaining> registrar is notified.
 
-5. If the transfer was B<approved>, the object is transferred to the B<gaining> registrar. Any outstanding payments for the domain name are also transferred to the B<gaining> registrar. If the Technical Contact for the domain name matches the B<losing> registrar, then this is also changed to the B<gaining> registrar.
+5. If the transfer was B<approved>, the object is transferred to the B<gaining> registrar. If the Technical Contact for the domain name matches the B<losing> registrar, then this is also changed to the B<gaining> registrar.
 
-6. If the transfer is not explicitly I<approved> or I<rejected> by the B<losing> registrar B<within five calendar days>, then the transfer is automatically marked as C<rejected>. The transfer may still be actioned if the B<gaining> registrar can acquire written authorisation (ideally on company letterhead) from the Registrant.
+6. If the transfer B<was not> submitted with the C<authinfo> parameter, and is not explicitly I<approved> or I<rejected> by the B<losing> registrar B<within five calendar days>, then the transfer is automatically marked as C<rejected>. The transfer may still be actioned if the B<gaining> registrar can acquire written authorisation (ideally on company letterhead) from the Registrant.
+
+7. If the transfer B<was> submitted with the C<authinfo> parameter, and is not explicitly I<approved> or I<rejected> by the B<losing> registrar B<within five calendar days>, then the transfer is approved as per 5 above.
 
 	my $query = WWW::CNic->new(
 		command		=> 'start_transfer',
@@ -705,6 +666,7 @@ You can B<start> a transfer process for one or more domain names using the C<sta
 	);
 
 	$query->set(domains => ['example.uk.com']);
+	$query->set(authinfo => ['abc123xyz']); # optional
 
 	my $response = $query->execute;
 
@@ -1030,7 +992,7 @@ We're always keen to find out about how people are using our Toolkit system, and
 
 =head1 Copyright
 
-This module is (c) 2007 CentralNic Ltd. All rights reserved. This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+This module is (c) 2010 CentralNic Ltd. All rights reserved. This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
 
 =head1 See Also
 
